package com.unis.base.client;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.unis.base.common.vo.TyCrkxxVO;
import com.unis.common.utils.ResponseWrapper;

/**
 * @author zhengbodang
 * @version 1.0
 * @Title TyCrkxxController
 * @ProjectName 出入库结算信息 Controller
 * @Description
 * @date 2019/07/22 17点26分
 */
@FeignClient(name = "base-server")
@Component
@Api(value = "出入库信息 ", tags = "出入库信息维护")
public interface ExitDepotController {

	/**
	 * @author zhengbodang
	 * @Description 获取出入库结算列表
	 * @param
	 * @return 出入库结算列表
	 */
	@ApiOperation(value = "出入库结算列表", notes = "参数：")
	@PostMapping(value = "/exitDepotList")
    public ResponseWrapper getTyCrkjsxxList(@RequestBody TyCrkxxVO tyCrkxxVO);

	/**
	 * @author zhengbodang
	 * @Description 分页获取出入库信息列表
	 * @param
	 * @return
	 */
	@ApiOperation(value = "分页获取出入库信息列表", notes = "参数：")
	@PostMapping(value = "/exitDepotPage/{pageNum}/{pageSize}")
    public ResponseWrapper getTyCrkjsxxPage(@RequestBody TyCrkxxVO tyCrkxxVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize);

	/**
	 * @author zhengbodang
	 * @Description 新增出入库结算信息
	 * @param 廒间信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/exitDepot")
	@ApiOperation(value = "新增出入库信息", notes = "参数：")
    public ResponseWrapper insert(@RequestBody TyCrkxxVO tyCrkxxVO);

	/**
	 * @author zhengbodang
	 * @Description 更新出入库结算信息
	 * @param
	 * @return 新增状态
	 */
	@PutMapping(value = "/exitDepot")
	@ApiOperation(value = "更新出入库结算信息", notes = "参数：")
    public ResponseWrapper update(@RequestBody TyCrkxxVO tyCrkxxVO);

	/**
	 * @author zhengbodang
	 * @Description 删除出入库结算信息
	 * @param
	 * @return 状态
	 */
	@DeleteMapping(value="/exitDepot/{jsid}")
	@ApiOperation(value = "根据出入库结算信息编号删除出入库结算信息", notes = "参数：")
	public ResponseWrapper delete(@PathVariable("jsid") String crkid);

	/**
	 * @author zhengbodang
	 * @Description 删除出入库结算信息
	 * @param
	 * @return 状态
	 */
	@GetMapping(value="/exitDepot/{crkid}")
	@ApiOperation(value = "根据出入库信息编号获取出入库信息", notes = "参数：")
	public ResponseWrapper getDAjxxsjyByajbh(@PathVariable("crkid") String crkid);
}
