package com.unis.base.client;

import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.unis.base.common.vo.TyZjxxmxbVO;
import com.unis.common.utils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * @author zhengbodang
 * @version 1.0
 * @Title DAjxxsjyController
 * @ProjectName 质检信息 Controller
 * @Description
 * @date 2019/07/22 17点26分
 */
@FeignClient(name = "base-server")
@Component
@Api(value = "质检信息 ", tags = "质检信息 维护")
public interface QualityInfoController {

	/**
	 * @author zhengbodang
	 * @Description 获取质检列表
	 * @param
	 * @return 质检列表
	 */
	@ApiOperation(value = "质检列表", notes = "参数：")
	@PostMapping(value = "/qualityInfoList")
    public ResponseWrapper getTyZjxxmxbList(@RequestBody TyZjxxmxbVO tyZjxxmxbVO);

	/**
	 * @author zhengbodang
	 * @Description 分页获取质检信息列表
	 * @param
	 * @return
	 */
	@ApiOperation(value = "分页获取质检信息列表", notes = "参数：")
	@PostMapping(value = "/qualityInfoPage/{pageNum}/{pageSize}")
    public ResponseWrapper getTyZjxxmxbPage(@RequestBody TyZjxxmxbVO tyZjxxmxbVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize);

	/**
	 * @author zhengbodang
	 * @Description 新增质检信息
	 * @param 廒间信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/qualityInfo")
	@ApiOperation(value = "新增质检信息", notes = "参数：")
    public ResponseWrapper insert(@RequestBody TyZjxxmxbVO tyZjxxmxbVO);

	/**
	 * @author zhengbodang
	 * @Description 更新质检信息
	 * @param
	 * @return 新增状态
	 */
	@PutMapping(value = "/qualityInfo")
	@ApiOperation(value = "更新质检信息", notes = "参数：")
    public ResponseWrapper update(@RequestBody TyZjxxmxbVO tyZjxxmxbVO);

	/**
	 * @author zhengbodang
	 * @Description 删除质检信息
	 * @param
	 * @return 状态
	 */
	@DeleteMapping(value="/qualityInfo/{zjxxid}")
	@ApiOperation(value = "根据质检信息编号删除质检信息", notes = "参数：")
	public ResponseWrapper delete(@PathVariable("zjxxid") String zjxxid);

	/**
	 * @author zhengbodang
	 * @Description 删除质检信息
	 * @param
	 * @return 状态
	 */
	@GetMapping(value="/qualityInfo/{zjxxid}")
	@ApiOperation(value = "获取质检信息", notes = "参数：")
	public ResponseWrapper getTyZjxxmxbByTfzyid(@PathVariable("zjxxid") String zjxxid);

	/**
	 * 根据zjxxid获取所有的质检信息
	 * @param zjxxid
	 * @return
	 */
	@GetMapping(value="/qualityInfoByzjxxid/{zjxxid}")
	@ApiOperation(value = "获取质检信息", notes = "参数：")
	public ResponseWrapper  getAllZjxxmx(@PathVariable("zjxxid") String zjxxid);


	/**
	 * @author zhengbodang
	 * @Description 新增质检信息
	 * @param 廒间信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/batchQualityInfo")
	@ApiOperation(value = "批量新增质检信息", notes = "参数：")
    public ResponseWrapper batchInserts(@RequestBody List<TyZjxxmxbVO> tyZjxxmxbVO);

}
