package com.unis.base.server.controller;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.github.pagehelper.PageInfo;
import com.unis.base.common.vo.TyXzzyxxHisVO;
import com.unis.base.common.vo.TyXzzyxxVO;
import com.unis.base.server.service.TyXzzyxxService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 * @author zhengbodang
 * @version 1.0
 * @Title DAjxxsjyController
 * @ProjectName 熏蒸作业信息 Controller
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "熏蒸作业信息 ", tags = "熏蒸作业信息 维护")
@Slf4j
public class FumigationOperationController {

	@Autowired
	private TyXzzyxxService tyXzzyxxService;

	/**
	 * @author zhengbodang
	 * @Description 获取熏蒸作业列表
	 * @param
	 * @return 熏蒸作业列表
	 */
	@ApiOperation(value = "熏蒸作业列表", notes = "参数：")
	@PostMapping(value = "/fumigationOperationList")
    public ResponseWrapper getTyXzzyxxList(@RequestBody TyXzzyxxVO tyXzzyxxVO){
        try {
        	List<TyXzzyxxVO> tyXzzyxxVOs = tyXzzyxxService.getTyXzzyxxList(tyXzzyxxVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), tyXzzyxxVOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 分页获取熏蒸作业信息列表
	 * @param
	 * @return
	 */
	@ApiOperation(value = "分页获取熏蒸作业信息列表", notes = "参数：")
	@PostMapping(value = "/fumigationOperationPage/{pageNum}/{pageSize}")
    public ResponseWrapper getTyXzzyxxPage(@RequestBody TyXzzyxxVO tyXzzyxxVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<TyXzzyxxVO> pageInfos =tyXzzyxxService.getTyXzzyxxPage(tyXzzyxxVO,pageNum,pageSize);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 新增熏蒸作业信息
	 * @param 廒间信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/fumigationOperation")
	@ApiOperation(value = "新增熏蒸作业信息", notes = "参数：方案编号，方案名称")
    public ResponseWrapper insert(@RequestBody TyXzzyxxVO tyXzzyxxVO) {
		try{
			if(StringUtils.isEmpty(tyXzzyxxVO.getFabh())||StringUtils.isEmpty(tyXzzyxxVO.getFamc())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			int x = tyXzzyxxService.insert(tyXzzyxxVO);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "添加熏蒸作业信息失败,该熏蒸作业信息已存在", null);
			} else if (x==-1) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "添加熏蒸作业信息失败,该熏蒸作业信息不存在", null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 更新熏蒸作业信息
	 * @param
	 * @return 新增状态
	 */
	@PutMapping(value = "/fumigationOperation")
	@ApiOperation(value = "更新熏蒸作业信息", notes = "参数：熏蒸id")
    public ResponseWrapper update(@RequestBody TyXzzyxxVO tyXzzyxxVO) {
		try{
			if(StringUtils.isEmpty(tyXzzyxxVO.getXzzyid())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			int x = tyXzzyxxService.update(tyXzzyxxVO);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该熏蒸作业信息不存在", null);
			} else {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该熏蒸作业信息已被作废，不能进行更新",null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 删除熏蒸作业信息
	 * @param
	 * @return 状态
	 */
	@DeleteMapping(value="/fumigationOperation/{xzzyid}")
	@ApiOperation(value = "根据熏蒸作业信息编号删除熏蒸作业信息", notes = "参数：")
	public ResponseWrapper delete(@PathVariable("xzzyid") String xzzyid) {
		try{
			int x = tyXzzyxxService.delete(xzzyid);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				 return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请社会行政代码是否正确", null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 删除熏蒸作业信息
	 * @param
	 * @return 状态
	 */
	@GetMapping(value="/fumigationOperation/{xzzyid}")
	@ApiOperation(value = "获取熏蒸作业信息", notes = "参数：")
	public ResponseWrapper getTyXzzyxxByTfzyid(@PathVariable("xzzyid") String xzzyid) {
		try{
			TyXzzyxxVO tyXzzyxxVO = tyXzzyxxService.getXzzyxxByXzzyxxid(xzzyid);
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), tyXzzyxxVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * 熏蒸作业信息-更改备案状态
	 * @param tyXzzyxxVO
	 * @return
	 */
	@PostMapping(value = "/fumigationOperationStatus")
	@ApiOperation(value = "熏蒸作业信息-更改备案状态", notes = "参数：备案信息")
	public ResponseWrapper updateFumigationOperationStatus(@RequestBody TyXzzyxxHisVO tyXzzyxxHisVO) {
		try {
			if (tyXzzyxxHisVO.getSfba() == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			Integer i = tyXzzyxxService.updateFumigationOperationStatus(tyXzzyxxHisVO);
			if (i > 0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "操作成功");
			} else if (i==-1) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "保存成功-(只有已备案和已驳回才能添加记录)", null);
			} else if (i==-2) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "请输入驳回审批意见", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), "操作失败，请联系管理员");
			}
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
		}
	}
}
