package com.unis.base.server.controller;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.unis.base.common.vo.TyJhxxzbVO;
import com.unis.base.server.service.TyJhxxzbService;
import com.unis.common.utils.ResponseWrapper;

/**
 * @author zhengbodang
 * @version 1.0
 * @Title DAjxxsjyController
 * @ProjectName 计划信息主表 Controller
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "计划主表信息 ", tags = "计划主表信息维护")
@Slf4j
public class PlanMainController {
	@Autowired
	private TyJhxxzbService tyJhxxzbService;

	/**
	 * @author zhengbodang
	 * @Description 获取计划信息主表信息列表
	 * @param
	 * @return 计划信息主表信息列表
	 */
	@ApiOperation(value = "计划信息主表信息列表", notes = "参数：")
	@PostMapping(value = "/planMainList")
    public ResponseWrapper getTyCrkjsxxList(@RequestBody TyJhxxzbVO tyJhxxzbVO){
        try {
        	List<TyJhxxzbVO> tyJhxxzbVOs = tyJhxxzbService.getTyJhxxzbList(tyJhxxzbVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), tyJhxxzbVOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 分页获取计划信息主表信息列表
	 * @param
	 * @return
	 */
	@ApiOperation(value = "分页获取计划信息主表信息列表", notes = "参数：")
	@PostMapping(value = "/planMainPage/{pageNum}/{pageSize}")
    public ResponseWrapper getTyJhxxzbPage(@RequestBody TyJhxxzbVO tyJhxxzbVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<TyJhxxzbVO> pageInfos = new PageInfo<TyJhxxzbVO>(tyJhxxzbService.getTyJhxxzbPage(tyJhxxzbVO,pageNum,pageSize));
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 新增出入库结算信息
	 * @param 廒间信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/planMain")
	@ApiOperation(value = "新增计划信息主表信息", notes = "参数：计划号，计划标题")
    public ResponseWrapper insert(@RequestBody TyJhxxzbVO tyJhxxzbVO) {
		try{
			if(StringUtils.isEmpty(tyJhxxzbVO.getJhh())||StringUtils.isEmpty(tyJhxxzbVO.getJhbt())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			int x = tyJhxxzbService.insert(tyJhxxzbVO);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "添加计划信息主表信息失败,该出计划信息主表信息已存在", null);
			} else if (x==-1) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "添加计划信息主表信息失败,该计划信息主表信息不存在", null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 更新出入库结算信息
	 * @param
	 * @return 新增状态
	 */
	@PutMapping(value = "/planMain")
	@ApiOperation(value = "更新计划信息主表信息", notes = "参数：计划信息id")
    public ResponseWrapper update(@RequestBody TyJhxxzbVO tyJhxxzbVO) {
		try{
			if(StringUtils.isEmpty(tyJhxxzbVO.getJhxxid())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			int x = tyJhxxzbService.update(tyJhxxzbVO);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该计划信息主表信息不存在", null);
			} else {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该计划信息主表信息已被作废，不能进行更新",null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 删除出入库结算信息
	 * @param
	 * @return 状态
	 */
	@DeleteMapping(value="/planMain/{jhxxid}")
	@ApiOperation(value = "根据出入库结算信息编号删除出入库结算信息", notes = "参数：")
	public ResponseWrapper delete(@PathVariable("jhxxid") String jhxxid) {
		try{
			int x = tyJhxxzbService.delete(jhxxid);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				 return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请社会行政代码是否正确", null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author zhengbodang
	 * @Description 删除出入库结算信息
	 * @param
	 * @return 状态
	 */
	@GetMapping(value="/planMain/{jhxxid}")
	@ApiOperation(value = "根据结算信息编号获取出入库结算信息", notes = "参数：")
	public ResponseWrapper getDAjxxsjyByajbh(@PathVariable("jhxxid") String jhxxid) {
		try{
			TyJhxxzbVO tyJhxxzbVO = tyJhxxzbService.getJhxxzbByJhxxzbid(jhxxid);
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), tyJhxxzbVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

}
