package com.unis.base.server.service.impl;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.unis.base.common.vo.OiltankQueryVO;
import com.unis.base.common.vo.OiltankVO;
import com.unis.base.server.domain.OiltankDomain;
import com.unis.base.server.service.OiltankService;

/**
 * @author huangxing
 * @version 1.0
 * @Title DYgxxsjyServiceImpl
 * @ProjectName 油罐服务实现层
 * @Description
 * @date 2019/07/22 17点26分
 */
@Service
public class OiltankServiceImpl implements OiltankService {

	@Resource
	private OiltankDomain oiltankDomain;

	/**
	 * 获取油罐信息列表
	 * @param dYgxxsjyVO
	 * @return
	 */
	@Override
	public List<OiltankVO> getOiltankList(OiltankQueryVO dYgxxsjyVO) {
		return oiltankDomain.getOiltankList(dYgxxsjyVO);
	}

	/**
	 * 分页获取油罐信息列表
	 * @param dYgxxsjyVO
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@Override
	public List<OiltankVO> getOiltankPage(OiltankQueryVO dYgxxsjyVO, Integer pageNum, Integer pageSize) {
		PageHelper.startPage(pageNum, pageSize,"ygbh desc");
		return oiltankDomain.getOiltankList(dYgxxsjyVO);
	}

	/**
	 * 根据油罐编号获取油罐信息
	 * @param ygbh
	 * @return
	 */
	@Override
	public OiltankVO getOiltankInfoByygbh(String ygbh) {
		return oiltankDomain.getOiltankInfo(ygbh);
	}

	/**
	 * 更新油罐信息
	 * @param dYgxxsjyVO
	 * @return
	 */
	@Override
	public int update(OiltankVO oiltankVO) {
		return oiltankDomain.update(oiltankVO);
	}

	/**
	 * 根据油罐编号删除油罐信息
	 * @param ygbh
	 * @return
	 */
	@Override
	public int delete(String id) {
		return oiltankDomain.delete(id);
	}

	/**
	 * 删除油罐信息
	 * @param dAjxxsjyVO
	 * @return
	 */
	@Override
	public OiltankVO insert(OiltankVO dAjxxsjyVO) {
		return oiltankDomain.insert(dAjxxsjyVO);
	}
	/**
	 * 更新油罐申请状态（0 可编辑 1 不可编辑）
	 * @param ygbh
	 * @return
	 */
	public int updateSqzt(String ygbh,String sqzt){
		return oiltankDomain.updateSqzt(ygbh,sqzt);
	}

	@Override
	public boolean initData() {
		return oiltankDomain.initData();
	}

	@Override
	public List<OiltankVO> getOiltankPages(OiltankQueryVO oiltankVO, Integer pageNum, Integer pageSize) {
		PageHelper.startPage(pageNum, pageSize,null);
		return oiltankDomain.getOiltankPages(oiltankVO);
	}

	public OiltankVO getOilTankInfo(OiltankQueryVO oiltankQueryVO) {
		return oiltankDomain.getOilTankInfo(oiltankQueryVO);
	}

	public List<OiltankVO> getOilTankInfoList(OiltankQueryVO oiltankQueryVO) {
		return oiltankDomain.getOilTankInfoList(oiltankQueryVO);
	}

}
